import java.io
import java.rmi
import java.rmi.server
import typing



class DGC(java.rmi.Remote):
    def clean(self, objIDArray: typing.List[java.rmi.server.ObjID], long: int, vMID: 'VMID', boolean: bool) -> None: ...
    def dirty(self, objIDArray: typing.List[java.rmi.server.ObjID], long: int, lease: 'Lease') -> 'Lease': ...

class Lease(java.io.Serializable):
    def __init__(self, vMID: 'VMID', long: int): ...
    def getVMID(self) -> 'VMID': ...
    def getValue(self) -> int: ...

class VMID(java.io.Serializable):
    def __init__(self): ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def isUnique() -> bool: ...
    def toString(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.rmi.dgc")``.

    DGC: typing.Type[DGC]
    Lease: typing.Type[Lease]
    VMID: typing.Type[VMID]



import java
import java.awt
import java.io
import java.lang
import typing



class AffineTransform(java.lang.Cloneable, java.io.Serializable):
    TYPE_IDENTITY: typing.ClassVar[int] = ...
    TYPE_TRANSLATION: typing.ClassVar[int] = ...
    TYPE_UNIFORM_SCALE: typing.ClassVar[int] = ...
    TYPE_GENERAL_SCALE: typing.ClassVar[int] = ...
    TYPE_MASK_SCALE: typing.ClassVar[int] = ...
    TYPE_FLIP: typing.ClassVar[int] = ...
    TYPE_QUADRANT_ROTATION: typing.ClassVar[int] = ...
    TYPE_GENERAL_ROTATION: typing.ClassVar[int] = ...
    TYPE_MASK_ROTATION: typing.ClassVar[int] = ...
    TYPE_GENERAL_TRANSFORM: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float): ...
    @typing.overload
    def __init__(self, doubleArray: typing.List[float]): ...
    @typing.overload
    def __init__(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float): ...
    @typing.overload
    def __init__(self, floatArray: typing.List[float]): ...
    @typing.overload
    def __init__(self, affineTransform: 'AffineTransform'): ...
    def clone(self) -> typing.Any: ...
    def concatenate(self, affineTransform: 'AffineTransform') -> None: ...
    def createInverse(self) -> 'AffineTransform': ...
    def createTransformedShape(self, shape: java.awt.Shape) -> java.awt.Shape: ...
    @typing.overload
    def deltaTransform(self, point2D: 'Point2D', point2D2: 'Point2D') -> 'Point2D': ...
    @typing.overload
    def deltaTransform(self, doubleArray: typing.List[float], int: int, doubleArray2: typing.List[float], int2: int, int3: int) -> None: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getDeterminant(self) -> float: ...
    def getMatrix(self, doubleArray: typing.List[float]) -> None: ...
    @typing.overload
    @staticmethod
    def getQuadrantRotateInstance(int: int) -> 'AffineTransform': ...
    @typing.overload
    @staticmethod
    def getQuadrantRotateInstance(int: int, double: float, double2: float) -> 'AffineTransform': ...
    @typing.overload
    @staticmethod
    def getRotateInstance(double: float) -> 'AffineTransform': ...
    @typing.overload
    @staticmethod
    def getRotateInstance(double: float, double2: float) -> 'AffineTransform': ...
    @typing.overload
    @staticmethod
    def getRotateInstance(double: float, double2: float, double3: float) -> 'AffineTransform': ...
    @typing.overload
    @staticmethod
    def getRotateInstance(double: float, double2: float, double3: float, double4: float) -> 'AffineTransform': ...
    @staticmethod
    def getScaleInstance(double: float, double2: float) -> 'AffineTransform': ...
    def getScaleX(self) -> float: ...
    def getScaleY(self) -> float: ...
    @staticmethod
    def getShearInstance(double: float, double2: float) -> 'AffineTransform': ...
    def getShearX(self) -> float: ...
    def getShearY(self) -> float: ...
    @staticmethod
    def getTranslateInstance(double: float, double2: float) -> 'AffineTransform': ...
    def getTranslateX(self) -> float: ...
    def getTranslateY(self) -> float: ...
    def getType(self) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def inverseTransform(self, point2D: 'Point2D', point2D2: 'Point2D') -> 'Point2D': ...
    @typing.overload
    def inverseTransform(self, doubleArray: typing.List[float], int: int, doubleArray2: typing.List[float], int2: int, int3: int) -> None: ...
    def invert(self) -> None: ...
    def isIdentity(self) -> bool: ...
    def preConcatenate(self, affineTransform: 'AffineTransform') -> None: ...
    @typing.overload
    def quadrantRotate(self, int: int) -> None: ...
    @typing.overload
    def quadrantRotate(self, int: int, double: float, double2: float) -> None: ...
    @typing.overload
    def rotate(self, double: float) -> None: ...
    @typing.overload
    def rotate(self, double: float, double2: float) -> None: ...
    @typing.overload
    def rotate(self, double: float, double2: float, double3: float) -> None: ...
    @typing.overload
    def rotate(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    def scale(self, double: float, double2: float) -> None: ...
    def setToIdentity(self) -> None: ...
    @typing.overload
    def setToQuadrantRotation(self, int: int) -> None: ...
    @typing.overload
    def setToQuadrantRotation(self, int: int, double: float, double2: float) -> None: ...
    @typing.overload
    def setToRotation(self, double: float) -> None: ...
    @typing.overload
    def setToRotation(self, double: float, double2: float) -> None: ...
    @typing.overload
    def setToRotation(self, double: float, double2: float, double3: float) -> None: ...
    @typing.overload
    def setToRotation(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    def setToScale(self, double: float, double2: float) -> None: ...
    def setToShear(self, double: float, double2: float) -> None: ...
    def setToTranslation(self, double: float, double2: float) -> None: ...
    @typing.overload
    def setTransform(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
    @typing.overload
    def setTransform(self, affineTransform: 'AffineTransform') -> None: ...
    def shear(self, double: float, double2: float) -> None: ...
    def toString(self) -> str: ...
    @typing.overload
    def transform(self, point2D: 'Point2D', point2D2: 'Point2D') -> 'Point2D': ...
    @typing.overload
    def transform(self, doubleArray: typing.List[float], int: int, doubleArray2: typing.List[float], int2: int, int3: int) -> None: ...
    @typing.overload
    def transform(self, doubleArray: typing.List[float], int: int, floatArray: typing.List[float], int2: int, int3: int) -> None: ...
    @typing.overload
    def transform(self, floatArray: typing.List[float], int: int, doubleArray: typing.List[float], int2: int, int3: int) -> None: ...
    @typing.overload
    def transform(self, floatArray: typing.List[float], int: int, floatArray2: typing.List[float], int2: int, int3: int) -> None: ...
    @typing.overload
    def transform(self, point2DArray: typing.List['Point2D'], int: int, point2DArray2: typing.List['Point2D'], int2: int, int3: int) -> None: ...
    def translate(self, double: float, double2: float) -> None: ...

class Area(java.awt.Shape, java.lang.Cloneable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, shape: java.awt.Shape): ...
    def add(self, area: 'Area') -> None: ...
    def clone(self) -> typing.Any: ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, point2D: 'Point2D') -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def createTransformedArea(self, affineTransform: AffineTransform) -> 'Area': ...
    @typing.overload
    def equals(self, area: 'Area') -> bool: ...
    @typing.overload
    def equals(self, object: typing.Any) -> bool: ...
    def exclusiveOr(self, area: 'Area') -> None: ...
    def getBounds(self) -> java.awt.Rectangle: ...
    def getBounds2D(self) -> 'Rectangle2D': ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> 'PathIterator': ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> 'PathIterator': ...
    def intersect(self, area: 'Area') -> None: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def isEmpty(self) -> bool: ...
    def isPolygonal(self) -> bool: ...
    def isRectangular(self) -> bool: ...
    def isSingular(self) -> bool: ...
    def reset(self) -> None: ...
    def subtract(self, area: 'Area') -> None: ...
    def transform(self, affineTransform: AffineTransform) -> None: ...

class Dimension2D(java.lang.Cloneable):
    def clone(self) -> typing.Any: ...
    def getHeight(self) -> float: ...
    def getWidth(self) -> float: ...
    @typing.overload
    def setSize(self, double: float, double2: float) -> None: ...
    @typing.overload
    def setSize(self, dimension2D: 'Dimension2D') -> None: ...

class IllegalPathStateException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class NoninvertibleTransformException(java.lang.Exception):
    def __init__(self, string: str): ...

class PathIterator:
    WIND_EVEN_ODD: typing.ClassVar[int] = ...
    WIND_NON_ZERO: typing.ClassVar[int] = ...
    SEG_MOVETO: typing.ClassVar[int] = ...
    SEG_LINETO: typing.ClassVar[int] = ...
    SEG_QUADTO: typing.ClassVar[int] = ...
    SEG_CUBICTO: typing.ClassVar[int] = ...
    SEG_CLOSE: typing.ClassVar[int] = ...
    @typing.overload
    def currentSegment(self, doubleArray: typing.List[float]) -> int: ...
    @typing.overload
    def currentSegment(self, floatArray: typing.List[float]) -> int: ...
    def getWindingRule(self) -> int: ...
    def isDone(self) -> bool: ...
    def next(self) -> None: ...

class RectangularShape(java.awt.Shape, java.lang.Cloneable):
    def clone(self) -> typing.Any: ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, point2D: 'Point2D') -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def getBounds(self) -> java.awt.Rectangle: ...
    def getCenterX(self) -> float: ...
    def getCenterY(self) -> float: ...
    def getFrame(self) -> 'Rectangle2D': ...
    def getHeight(self) -> float: ...
    def getMaxX(self) -> float: ...
    def getMaxY(self) -> float: ...
    def getMinX(self) -> float: ...
    def getMinY(self) -> float: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    def getWidth(self) -> float: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def isEmpty(self) -> bool: ...
    @typing.overload
    def setFrame(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setFrame(self, point2D: 'Point2D', dimension2D: Dimension2D) -> None: ...
    @typing.overload
    def setFrame(self, rectangle2D: 'Rectangle2D') -> None: ...
    @typing.overload
    def setFrameFromCenter(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setFrameFromCenter(self, point2D: 'Point2D', point2D2: 'Point2D') -> None: ...
    @typing.overload
    def setFrameFromDiagonal(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setFrameFromDiagonal(self, point2D: 'Point2D', point2D2: 'Point2D') -> None: ...

class FlatteningPathIterator(PathIterator):
    @typing.overload
    def __init__(self, pathIterator: PathIterator, double: float): ...
    @typing.overload
    def __init__(self, pathIterator: PathIterator, double: float, int: int): ...
    @typing.overload
    def currentSegment(self, doubleArray: typing.List[float]) -> int: ...
    @typing.overload
    def currentSegment(self, floatArray: typing.List[float]) -> int: ...
    def getFlatness(self) -> float: ...
    def getRecursionLimit(self) -> int: ...
    def getWindingRule(self) -> int: ...
    def isDone(self) -> bool: ...
    def next(self) -> None: ...

class Arc2D(RectangularShape):
    OPEN: typing.ClassVar[int] = ...
    CHORD: typing.ClassVar[int] = ...
    PIE: typing.ClassVar[int] = ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    @typing.overload
    def contains(self, point2D: 'Point2D') -> bool: ...
    def containsAngle(self, double: float) -> bool: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAngleExtent(self) -> float: ...
    def getAngleStart(self) -> float: ...
    def getArcType(self) -> int: ...
    def getBounds2D(self) -> 'Rectangle2D': ...
    def getEndPoint(self) -> 'Point2D': ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    def getStartPoint(self) -> 'Point2D': ...
    def hashCode(self) -> int: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def setAngleExtent(self, double: float) -> None: ...
    @typing.overload
    def setAngleStart(self, double: float) -> None: ...
    @typing.overload
    def setAngleStart(self, point2D: 'Point2D') -> None: ...
    @typing.overload
    def setAngles(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setAngles(self, point2D: 'Point2D', point2D2: 'Point2D') -> None: ...
    @typing.overload
    def setArc(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float, int: int) -> None: ...
    @typing.overload
    def setArc(self, arc2D: 'Arc2D') -> None: ...
    @typing.overload
    def setArc(self, point2D: 'Point2D', dimension2D: Dimension2D, double: float, double2: float, int: int) -> None: ...
    @typing.overload
    def setArc(self, rectangle2D: 'Rectangle2D', double: float, double2: float, int: int) -> None: ...
    def setArcByCenter(self, double: float, double2: float, double3: float, double4: float, double5: float, int: int) -> None: ...
    def setArcByTangent(self, point2D: 'Point2D', point2D2: 'Point2D', point2D3: 'Point2D', double: float) -> None: ...
    def setArcType(self, int: int) -> None: ...
    @typing.overload
    def setFrame(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setFrame(self, point2D: 'Point2D', dimension2D: Dimension2D) -> None: ...
    @typing.overload
    def setFrame(self, rectangle2D: 'Rectangle2D') -> None: ...
    class Double(java.awt.geom.Arc2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        width: float = ...
        height: float = ...
        start: float = ...
        extent: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float, int: int): ...
        @typing.overload
        def __init__(self, int: int): ...
        @typing.overload
        def __init__(self, rectangle2D: 'Rectangle2D', double: float, double2: float, int: int): ...
        def getAngleExtent(self) -> float: ...
        def getAngleStart(self) -> float: ...
        def getHeight(self) -> float: ...
        def getWidth(self) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def isEmpty(self) -> bool: ...
        def setAngleExtent(self, double: float) -> None: ...
        @typing.overload
        def setAngleStart(self, double: float) -> None: ...
        @typing.overload
        def setAngleStart(self, point2D: 'Point2D') -> None: ...
        @typing.overload
        def setArc(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float, int: int) -> None: ...
        @typing.overload
        def setArc(self, arc2D: 'Arc2D') -> None: ...
        @typing.overload
        def setArc(self, point2D: 'Point2D', dimension2D: Dimension2D, double: float, double2: float, int: int) -> None: ...
        @typing.overload
        def setArc(self, rectangle2D: 'Rectangle2D', double: float, double2: float, int: int) -> None: ...
    class Float(java.awt.geom.Arc2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        width: float = ...
        height: float = ...
        start: float = ...
        extent: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float, int: int): ...
        @typing.overload
        def __init__(self, int: int): ...
        @typing.overload
        def __init__(self, rectangle2D: 'Rectangle2D', float: float, float2: float, int: int): ...
        def getAngleExtent(self) -> float: ...
        def getAngleStart(self) -> float: ...
        def getHeight(self) -> float: ...
        def getWidth(self) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def isEmpty(self) -> bool: ...
        def setAngleExtent(self, double: float) -> None: ...
        @typing.overload
        def setAngleStart(self, double: float) -> None: ...
        @typing.overload
        def setAngleStart(self, point2D: 'Point2D') -> None: ...
        @typing.overload
        def setArc(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float, int: int) -> None: ...
        @typing.overload
        def setArc(self, arc2D: 'Arc2D') -> None: ...
        @typing.overload
        def setArc(self, point2D: 'Point2D', dimension2D: Dimension2D, double: float, double2: float, int: int) -> None: ...
        @typing.overload
        def setArc(self, rectangle2D: 'Rectangle2D', double: float, double2: float, int: int) -> None: ...

class CubicCurve2D(java.awt.Shape, java.lang.Cloneable):
    def clone(self) -> typing.Any: ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, point2D: 'Point2D') -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def getBounds(self) -> java.awt.Rectangle: ...
    def getCtrlP1(self) -> 'Point2D': ...
    def getCtrlP2(self) -> 'Point2D': ...
    def getCtrlX1(self) -> float: ...
    def getCtrlX2(self) -> float: ...
    def getCtrlY1(self) -> float: ...
    def getCtrlY2(self) -> float: ...
    @typing.overload
    def getFlatness(self) -> float: ...
    @typing.overload
    @staticmethod
    def getFlatness(double: float, double2: float, double3: float, double4: float, double5: float, double6: float, double7: float, double8: float) -> float: ...
    @typing.overload
    @staticmethod
    def getFlatness(doubleArray: typing.List[float], int: int) -> float: ...
    @typing.overload
    def getFlatnessSq(self) -> float: ...
    @typing.overload
    @staticmethod
    def getFlatnessSq(double: float, double2: float, double3: float, double4: float, double5: float, double6: float, double7: float, double8: float) -> float: ...
    @typing.overload
    @staticmethod
    def getFlatnessSq(doubleArray: typing.List[float], int: int) -> float: ...
    def getP1(self) -> 'Point2D': ...
    def getP2(self) -> 'Point2D': ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    def getX1(self) -> float: ...
    def getX2(self) -> float: ...
    def getY1(self) -> float: ...
    def getY2(self) -> float: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    @typing.overload
    def setCurve(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float, double7: float, double8: float) -> None: ...
    @typing.overload
    def setCurve(self, doubleArray: typing.List[float], int: int) -> None: ...
    @typing.overload
    def setCurve(self, cubicCurve2D: 'CubicCurve2D') -> None: ...
    @typing.overload
    def setCurve(self, point2D: 'Point2D', point2D2: 'Point2D', point2D3: 'Point2D', point2D4: 'Point2D') -> None: ...
    @typing.overload
    def setCurve(self, point2DArray: typing.List['Point2D'], int: int) -> None: ...
    @typing.overload
    @staticmethod
    def solveCubic(doubleArray: typing.List[float]) -> int: ...
    @typing.overload
    @staticmethod
    def solveCubic(doubleArray: typing.List[float], doubleArray2: typing.List[float]) -> int: ...
    @typing.overload
    @staticmethod
    def subdivide(doubleArray: typing.List[float], int: int, doubleArray2: typing.List[float], int2: int, doubleArray3: typing.List[float], int3: int) -> None: ...
    @typing.overload
    @staticmethod
    def subdivide(cubicCurve2D: 'CubicCurve2D', cubicCurve2D2: 'CubicCurve2D', cubicCurve2D3: 'CubicCurve2D') -> None: ...
    @typing.overload
    def subdivide(self, cubicCurve2D: 'CubicCurve2D', cubicCurve2D2: 'CubicCurve2D') -> None: ...
    class Double(java.awt.geom.CubicCurve2D, java.io.Serializable):
        x1: float = ...
        y1: float = ...
        ctrlx1: float = ...
        ctrly1: float = ...
        ctrlx2: float = ...
        ctrly2: float = ...
        x2: float = ...
        y2: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float, double7: float, double8: float): ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getCtrlP1(self) -> 'Point2D': ...
        def getCtrlP2(self) -> 'Point2D': ...
        def getCtrlX1(self) -> float: ...
        def getCtrlX2(self) -> float: ...
        def getCtrlY1(self) -> float: ...
        def getCtrlY2(self) -> float: ...
        def getP1(self) -> 'Point2D': ...
        def getP2(self) -> 'Point2D': ...
        def getX1(self) -> float: ...
        def getX2(self) -> float: ...
        def getY1(self) -> float: ...
        def getY2(self) -> float: ...
        @typing.overload
        def setCurve(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float, double7: float, double8: float) -> None: ...
        @typing.overload
        def setCurve(self, doubleArray: typing.List[float], int: int) -> None: ...
        @typing.overload
        def setCurve(self, cubicCurve2D: 'CubicCurve2D') -> None: ...
        @typing.overload
        def setCurve(self, point2D: 'Point2D', point2D2: 'Point2D', point2D3: 'Point2D', point2D4: 'Point2D') -> None: ...
        @typing.overload
        def setCurve(self, point2DArray: typing.List['Point2D'], int: int) -> None: ...
    class Float(java.awt.geom.CubicCurve2D, java.io.Serializable):
        x1: float = ...
        y1: float = ...
        ctrlx1: float = ...
        ctrly1: float = ...
        ctrlx2: float = ...
        ctrly2: float = ...
        x2: float = ...
        y2: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float, float7: float, float8: float): ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getCtrlP1(self) -> 'Point2D': ...
        def getCtrlP2(self) -> 'Point2D': ...
        def getCtrlX1(self) -> float: ...
        def getCtrlX2(self) -> float: ...
        def getCtrlY1(self) -> float: ...
        def getCtrlY2(self) -> float: ...
        def getP1(self) -> 'Point2D': ...
        def getP2(self) -> 'Point2D': ...
        def getX1(self) -> float: ...
        def getX2(self) -> float: ...
        def getY1(self) -> float: ...
        def getY2(self) -> float: ...
        @typing.overload
        def setCurve(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float, double7: float, double8: float) -> None: ...
        @typing.overload
        def setCurve(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float, float7: float, float8: float) -> None: ...
        @typing.overload
        def setCurve(self, doubleArray: typing.List[float], int: int) -> None: ...
        @typing.overload
        def setCurve(self, cubicCurve2D: 'CubicCurve2D') -> None: ...
        @typing.overload
        def setCurve(self, point2D: 'Point2D', point2D2: 'Point2D', point2D3: 'Point2D', point2D4: 'Point2D') -> None: ...
        @typing.overload
        def setCurve(self, point2DArray: typing.List['Point2D'], int: int) -> None: ...

class Ellipse2D(RectangularShape):
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, point2D: 'Point2D') -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def equals(self, object: typing.Any) -> bool: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    class Double(java.awt.geom.Ellipse2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        width: float = ...
        height: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, double: float, double2: float, double3: float, double4: float): ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getHeight(self) -> float: ...
        def getWidth(self) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def isEmpty(self) -> bool: ...
        @typing.overload
        def setFrame(self, double: float, double2: float, double3: float, double4: float) -> None: ...
        @typing.overload
        def setFrame(self, point2D: 'Point2D', dimension2D: Dimension2D) -> None: ...
        @typing.overload
        def setFrame(self, rectangle2D: 'Rectangle2D') -> None: ...
    class Float(java.awt.geom.Ellipse2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        width: float = ...
        height: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, float: float, float2: float, float3: float, float4: float): ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getHeight(self) -> float: ...
        def getWidth(self) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def isEmpty(self) -> bool: ...
        @typing.overload
        def setFrame(self, double: float, double2: float, double3: float, double4: float) -> None: ...
        @typing.overload
        def setFrame(self, float: float, float2: float, float3: float, float4: float) -> None: ...
        @typing.overload
        def setFrame(self, point2D: 'Point2D', dimension2D: Dimension2D) -> None: ...
        @typing.overload
        def setFrame(self, rectangle2D: 'Rectangle2D') -> None: ...

class GeneralPath(java.awt.geom.Path2D.Float):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    @typing.overload
    def __init__(self, shape: java.awt.Shape): ...

class Line2D(java.awt.Shape, java.lang.Cloneable):
    def clone(self) -> typing.Any: ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, point2D: 'Point2D') -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def getBounds(self) -> java.awt.Rectangle: ...
    def getP1(self) -> 'Point2D': ...
    def getP2(self) -> 'Point2D': ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    def getX1(self) -> float: ...
    def getX2(self) -> float: ...
    def getY1(self) -> float: ...
    def getY2(self) -> float: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    @typing.overload
    def intersectsLine(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersectsLine(self, line2D: 'Line2D') -> bool: ...
    @staticmethod
    def linesIntersect(double: float, double2: float, double3: float, double4: float, double5: float, double6: float, double7: float, double8: float) -> bool: ...
    @typing.overload
    def ptLineDist(self, double: float, double2: float) -> float: ...
    @typing.overload
    def ptLineDist(self, point2D: 'Point2D') -> float: ...
    @typing.overload
    @staticmethod
    def ptLineDist(double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> float: ...
    @typing.overload
    def ptLineDistSq(self, double: float, double2: float) -> float: ...
    @typing.overload
    def ptLineDistSq(self, point2D: 'Point2D') -> float: ...
    @typing.overload
    @staticmethod
    def ptLineDistSq(double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> float: ...
    @typing.overload
    def ptSegDist(self, double: float, double2: float) -> float: ...
    @typing.overload
    def ptSegDist(self, point2D: 'Point2D') -> float: ...
    @typing.overload
    @staticmethod
    def ptSegDist(double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> float: ...
    @typing.overload
    def ptSegDistSq(self, double: float, double2: float) -> float: ...
    @typing.overload
    def ptSegDistSq(self, point2D: 'Point2D') -> float: ...
    @typing.overload
    @staticmethod
    def ptSegDistSq(double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> float: ...
    @typing.overload
    def relativeCCW(self, double: float, double2: float) -> int: ...
    @typing.overload
    def relativeCCW(self, point2D: 'Point2D') -> int: ...
    @typing.overload
    @staticmethod
    def relativeCCW(double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> int: ...
    @typing.overload
    def setLine(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setLine(self, line2D: 'Line2D') -> None: ...
    @typing.overload
    def setLine(self, point2D: 'Point2D', point2D2: 'Point2D') -> None: ...
    class Double(java.awt.geom.Line2D, java.io.Serializable):
        x1: float = ...
        y1: float = ...
        x2: float = ...
        y2: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, double: float, double2: float, double3: float, double4: float): ...
        @typing.overload
        def __init__(self, point2D: 'Point2D', point2D2: 'Point2D'): ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getP1(self) -> 'Point2D': ...
        def getP2(self) -> 'Point2D': ...
        def getX1(self) -> float: ...
        def getX2(self) -> float: ...
        def getY1(self) -> float: ...
        def getY2(self) -> float: ...
        @typing.overload
        def setLine(self, double: float, double2: float, double3: float, double4: float) -> None: ...
        @typing.overload
        def setLine(self, line2D: 'Line2D') -> None: ...
        @typing.overload
        def setLine(self, point2D: 'Point2D', point2D2: 'Point2D') -> None: ...
    class Float(java.awt.geom.Line2D, java.io.Serializable):
        x1: float = ...
        y1: float = ...
        x2: float = ...
        y2: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, float: float, float2: float, float3: float, float4: float): ...
        @typing.overload
        def __init__(self, point2D: 'Point2D', point2D2: 'Point2D'): ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getP1(self) -> 'Point2D': ...
        def getP2(self) -> 'Point2D': ...
        def getX1(self) -> float: ...
        def getX2(self) -> float: ...
        def getY1(self) -> float: ...
        def getY2(self) -> float: ...
        @typing.overload
        def setLine(self, double: float, double2: float, double3: float, double4: float) -> None: ...
        @typing.overload
        def setLine(self, float: float, float2: float, float3: float, float4: float) -> None: ...
        @typing.overload
        def setLine(self, line2D: 'Line2D') -> None: ...
        @typing.overload
        def setLine(self, point2D: 'Point2D', point2D2: 'Point2D') -> None: ...

class Path2D(java.awt.Shape, java.lang.Cloneable):
    WIND_EVEN_ODD: typing.ClassVar[int] = ...
    WIND_NON_ZERO: typing.ClassVar[int] = ...
    @typing.overload
    def append(self, pathIterator: PathIterator, boolean: bool) -> None: ...
    @typing.overload
    def append(self, shape: java.awt.Shape, boolean: bool) -> None: ...
    def clone(self) -> typing.Any: ...
    def closePath(self) -> None: ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, point2D: 'Point2D') -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    @typing.overload
    @staticmethod
    def contains(pathIterator: PathIterator, double: float, double2: float) -> bool: ...
    @typing.overload
    @staticmethod
    def contains(pathIterator: PathIterator, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    @staticmethod
    def contains(pathIterator: PathIterator, point2D: 'Point2D') -> bool: ...
    @typing.overload
    @staticmethod
    def contains(pathIterator: PathIterator, rectangle2D: 'Rectangle2D') -> bool: ...
    def createTransformedShape(self, affineTransform: AffineTransform) -> java.awt.Shape: ...
    def curveTo(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
    def getBounds(self) -> java.awt.Rectangle: ...
    def getCurrentPoint(self) -> 'Point2D': ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    def getWindingRule(self) -> int: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    @typing.overload
    @staticmethod
    def intersects(pathIterator: PathIterator, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    @staticmethod
    def intersects(pathIterator: PathIterator, rectangle2D: 'Rectangle2D') -> bool: ...
    def lineTo(self, double: float, double2: float) -> None: ...
    def moveTo(self, double: float, double2: float) -> None: ...
    def quadTo(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    def reset(self) -> None: ...
    def setWindingRule(self, int: int) -> None: ...
    def transform(self, affineTransform: AffineTransform) -> None: ...
    def trimToSize(self) -> None: ...
    class Double(java.awt.geom.Path2D, java.io.Serializable):
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, int: int): ...
        @typing.overload
        def __init__(self, int: int, int2: int): ...
        @typing.overload
        def __init__(self, shape: java.awt.Shape): ...
        @typing.overload
        def __init__(self, shape: java.awt.Shape, affineTransform: AffineTransform): ...
        @typing.overload
        def append(self, pathIterator: PathIterator, boolean: bool) -> None: ...
        @typing.overload
        def append(self, shape: java.awt.Shape, boolean: bool) -> None: ...
        def clone(self) -> typing.Any: ...
        def curveTo(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        @typing.overload
        def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
        @typing.overload
        def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
        def lineTo(self, double: float, double2: float) -> None: ...
        def moveTo(self, double: float, double2: float) -> None: ...
        def quadTo(self, double: float, double2: float, double3: float, double4: float) -> None: ...
        def transform(self, affineTransform: AffineTransform) -> None: ...
        def trimToSize(self) -> None: ...
    class Float(java.awt.geom.Path2D, java.io.Serializable):
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, int: int): ...
        @typing.overload
        def __init__(self, int: int, int2: int): ...
        @typing.overload
        def __init__(self, shape: java.awt.Shape): ...
        @typing.overload
        def __init__(self, shape: java.awt.Shape, affineTransform: AffineTransform): ...
        @typing.overload
        def append(self, pathIterator: PathIterator, boolean: bool) -> None: ...
        @typing.overload
        def append(self, shape: java.awt.Shape, boolean: bool) -> None: ...
        def clone(self) -> typing.Any: ...
        @typing.overload
        def curveTo(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
        @typing.overload
        def curveTo(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float) -> None: ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        @typing.overload
        def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
        @typing.overload
        def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
        @typing.overload
        def lineTo(self, double: float, double2: float) -> None: ...
        @typing.overload
        def lineTo(self, float: float, float2: float) -> None: ...
        @typing.overload
        def moveTo(self, double: float, double2: float) -> None: ...
        @typing.overload
        def moveTo(self, float: float, float2: float) -> None: ...
        @typing.overload
        def quadTo(self, double: float, double2: float, double3: float, double4: float) -> None: ...
        @typing.overload
        def quadTo(self, float: float, float2: float, float3: float, float4: float) -> None: ...
        def transform(self, affineTransform: AffineTransform) -> None: ...
        def trimToSize(self) -> None: ...

class Point2D(java.lang.Cloneable):
    def clone(self) -> typing.Any: ...
    @typing.overload
    def distance(self, double: float, double2: float) -> float: ...
    @typing.overload
    def distance(self, point2D: 'Point2D') -> float: ...
    @typing.overload
    @staticmethod
    def distance(double: float, double2: float, double3: float, double4: float) -> float: ...
    @typing.overload
    def distanceSq(self, double: float, double2: float) -> float: ...
    @typing.overload
    def distanceSq(self, point2D: 'Point2D') -> float: ...
    @typing.overload
    @staticmethod
    def distanceSq(double: float, double2: float, double3: float, double4: float) -> float: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def setLocation(self, double: float, double2: float) -> None: ...
    @typing.overload
    def setLocation(self, point2D: 'Point2D') -> None: ...
    class Double(java.awt.geom.Point2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, double: float, double2: float): ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        @typing.overload
        def setLocation(self, double: float, double2: float) -> None: ...
        @typing.overload
        def setLocation(self, point2D: 'Point2D') -> None: ...
        def toString(self) -> str: ...
    class Float(java.awt.geom.Point2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, float: float, float2: float): ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        @typing.overload
        def setLocation(self, double: float, double2: float) -> None: ...
        @typing.overload
        def setLocation(self, float: float, float2: float) -> None: ...
        @typing.overload
        def setLocation(self, point2D: 'Point2D') -> None: ...
        def toString(self) -> str: ...

class QuadCurve2D(java.awt.Shape, java.lang.Cloneable):
    def clone(self) -> typing.Any: ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, point2D: Point2D) -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def getBounds(self) -> java.awt.Rectangle: ...
    def getCtrlPt(self) -> Point2D: ...
    def getCtrlX(self) -> float: ...
    def getCtrlY(self) -> float: ...
    @typing.overload
    def getFlatness(self) -> float: ...
    @typing.overload
    @staticmethod
    def getFlatness(double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> float: ...
    @typing.overload
    @staticmethod
    def getFlatness(doubleArray: typing.List[float], int: int) -> float: ...
    @typing.overload
    def getFlatnessSq(self) -> float: ...
    @typing.overload
    @staticmethod
    def getFlatnessSq(double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> float: ...
    @typing.overload
    @staticmethod
    def getFlatnessSq(doubleArray: typing.List[float], int: int) -> float: ...
    def getP1(self) -> Point2D: ...
    def getP2(self) -> Point2D: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    def getX1(self) -> float: ...
    def getX2(self) -> float: ...
    def getY1(self) -> float: ...
    def getY2(self) -> float: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    @typing.overload
    def setCurve(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
    @typing.overload
    def setCurve(self, doubleArray: typing.List[float], int: int) -> None: ...
    @typing.overload
    def setCurve(self, point2D: Point2D, point2D2: Point2D, point2D3: Point2D) -> None: ...
    @typing.overload
    def setCurve(self, point2DArray: typing.List[Point2D], int: int) -> None: ...
    @typing.overload
    def setCurve(self, quadCurve2D: 'QuadCurve2D') -> None: ...
    @typing.overload
    @staticmethod
    def solveQuadratic(doubleArray: typing.List[float]) -> int: ...
    @typing.overload
    @staticmethod
    def solveQuadratic(doubleArray: typing.List[float], doubleArray2: typing.List[float]) -> int: ...
    @typing.overload
    @staticmethod
    def subdivide(doubleArray: typing.List[float], int: int, doubleArray2: typing.List[float], int2: int, doubleArray3: typing.List[float], int3: int) -> None: ...
    @typing.overload
    @staticmethod
    def subdivide(quadCurve2D: 'QuadCurve2D', quadCurve2D2: 'QuadCurve2D', quadCurve2D3: 'QuadCurve2D') -> None: ...
    @typing.overload
    def subdivide(self, quadCurve2D: 'QuadCurve2D', quadCurve2D2: 'QuadCurve2D') -> None: ...
    class Double(java.awt.geom.QuadCurve2D, java.io.Serializable):
        x1: float = ...
        y1: float = ...
        ctrlx: float = ...
        ctrly: float = ...
        x2: float = ...
        y2: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float): ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getCtrlPt(self) -> Point2D: ...
        def getCtrlX(self) -> float: ...
        def getCtrlY(self) -> float: ...
        def getP1(self) -> Point2D: ...
        def getP2(self) -> Point2D: ...
        def getX1(self) -> float: ...
        def getX2(self) -> float: ...
        def getY1(self) -> float: ...
        def getY2(self) -> float: ...
        @typing.overload
        def setCurve(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
        @typing.overload
        def setCurve(self, doubleArray: typing.List[float], int: int) -> None: ...
        @typing.overload
        def setCurve(self, point2D: Point2D, point2D2: Point2D, point2D3: Point2D) -> None: ...
        @typing.overload
        def setCurve(self, point2DArray: typing.List[Point2D], int: int) -> None: ...
        @typing.overload
        def setCurve(self, quadCurve2D: 'QuadCurve2D') -> None: ...
    class Float(java.awt.geom.QuadCurve2D, java.io.Serializable):
        x1: float = ...
        y1: float = ...
        ctrlx: float = ...
        ctrly: float = ...
        x2: float = ...
        y2: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float): ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getCtrlPt(self) -> Point2D: ...
        def getCtrlX(self) -> float: ...
        def getCtrlY(self) -> float: ...
        def getP1(self) -> Point2D: ...
        def getP2(self) -> Point2D: ...
        def getX1(self) -> float: ...
        def getX2(self) -> float: ...
        def getY1(self) -> float: ...
        def getY2(self) -> float: ...
        @typing.overload
        def setCurve(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
        @typing.overload
        def setCurve(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float) -> None: ...
        @typing.overload
        def setCurve(self, doubleArray: typing.List[float], int: int) -> None: ...
        @typing.overload
        def setCurve(self, point2D: Point2D, point2D2: Point2D, point2D3: Point2D) -> None: ...
        @typing.overload
        def setCurve(self, point2DArray: typing.List[Point2D], int: int) -> None: ...
        @typing.overload
        def setCurve(self, quadCurve2D: 'QuadCurve2D') -> None: ...

class Rectangle2D(RectangularShape):
    OUT_LEFT: typing.ClassVar[int] = ...
    OUT_TOP: typing.ClassVar[int] = ...
    OUT_RIGHT: typing.ClassVar[int] = ...
    OUT_BOTTOM: typing.ClassVar[int] = ...
    @typing.overload
    def add(self, double: float, double2: float) -> None: ...
    @typing.overload
    def add(self, point2D: Point2D) -> None: ...
    @typing.overload
    def add(self, rectangle2D: 'Rectangle2D') -> None: ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def contains(self, point2D: Point2D) -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: 'Rectangle2D') -> bool: ...
    def createIntersection(self, rectangle2D: 'Rectangle2D') -> 'Rectangle2D': ...
    def createUnion(self, rectangle2D: 'Rectangle2D') -> 'Rectangle2D': ...
    def equals(self, object: typing.Any) -> bool: ...
    def getBounds2D(self) -> 'Rectangle2D': ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def intersect(rectangle2D: 'Rectangle2D', rectangle2D2: 'Rectangle2D', rectangle2D3: 'Rectangle2D') -> None: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersects(self, rectangle2D: 'Rectangle2D') -> bool: ...
    @typing.overload
    def intersectsLine(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def intersectsLine(self, line2D: Line2D) -> bool: ...
    @typing.overload
    def outcode(self, double: float, double2: float) -> int: ...
    @typing.overload
    def outcode(self, point2D: Point2D) -> int: ...
    @typing.overload
    def setFrame(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setFrame(self, point2D: Point2D, dimension2D: Dimension2D) -> None: ...
    @typing.overload
    def setFrame(self, rectangle2D: 'Rectangle2D') -> None: ...
    @typing.overload
    def setRect(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setRect(self, rectangle2D: 'Rectangle2D') -> None: ...
    @staticmethod
    def union(rectangle2D: 'Rectangle2D', rectangle2D2: 'Rectangle2D', rectangle2D3: 'Rectangle2D') -> None: ...
    class Double(java.awt.geom.Rectangle2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        width: float = ...
        height: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, double: float, double2: float, double3: float, double4: float): ...
        def createIntersection(self, rectangle2D: 'Rectangle2D') -> 'Rectangle2D': ...
        def createUnion(self, rectangle2D: 'Rectangle2D') -> 'Rectangle2D': ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getHeight(self) -> float: ...
        def getWidth(self) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def isEmpty(self) -> bool: ...
        @typing.overload
        def outcode(self, double: float, double2: float) -> int: ...
        @typing.overload
        def outcode(self, point2D: Point2D) -> int: ...
        @typing.overload
        def setRect(self, double: float, double2: float, double3: float, double4: float) -> None: ...
        @typing.overload
        def setRect(self, rectangle2D: 'Rectangle2D') -> None: ...
        def toString(self) -> str: ...
    class Float(java.awt.geom.Rectangle2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        width: float = ...
        height: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, float: float, float2: float, float3: float, float4: float): ...
        def createIntersection(self, rectangle2D: 'Rectangle2D') -> 'Rectangle2D': ...
        def createUnion(self, rectangle2D: 'Rectangle2D') -> 'Rectangle2D': ...
        def getBounds2D(self) -> 'Rectangle2D': ...
        def getHeight(self) -> float: ...
        def getWidth(self) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def isEmpty(self) -> bool: ...
        @typing.overload
        def outcode(self, double: float, double2: float) -> int: ...
        @typing.overload
        def outcode(self, point2D: Point2D) -> int: ...
        @typing.overload
        def setRect(self, double: float, double2: float, double3: float, double4: float) -> None: ...
        @typing.overload
        def setRect(self, float: float, float2: float, float3: float, float4: float) -> None: ...
        @typing.overload
        def setRect(self, rectangle2D: 'Rectangle2D') -> None: ...
        def toString(self) -> str: ...

class RoundRectangle2D(RectangularShape):
    @typing.overload
    def contains(self, point2D: Point2D) -> bool: ...
    @typing.overload
    def contains(self, rectangle2D: Rectangle2D) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float) -> bool: ...
    @typing.overload
    def contains(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getArcHeight(self) -> float: ...
    def getArcWidth(self) -> float: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform, double: float) -> PathIterator: ...
    @typing.overload
    def getPathIterator(self, affineTransform: AffineTransform) -> PathIterator: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def intersects(self, rectangle2D: Rectangle2D) -> bool: ...
    @typing.overload
    def intersects(self, double: float, double2: float, double3: float, double4: float) -> bool: ...
    @typing.overload
    def setFrame(self, point2D: Point2D, dimension2D: Dimension2D) -> None: ...
    @typing.overload
    def setFrame(self, rectangle2D: Rectangle2D) -> None: ...
    @typing.overload
    def setFrame(self, double: float, double2: float, double3: float, double4: float) -> None: ...
    @typing.overload
    def setRoundRect(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
    @typing.overload
    def setRoundRect(self, roundRectangle2D: 'RoundRectangle2D') -> None: ...
    class Double(java.awt.geom.RoundRectangle2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        width: float = ...
        height: float = ...
        arcwidth: float = ...
        archeight: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float): ...
        def getArcHeight(self) -> float: ...
        def getArcWidth(self) -> float: ...
        def getBounds2D(self) -> Rectangle2D: ...
        def getHeight(self) -> float: ...
        def getWidth(self) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def isEmpty(self) -> bool: ...
        @typing.overload
        def setRoundRect(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
        @typing.overload
        def setRoundRect(self, roundRectangle2D: 'RoundRectangle2D') -> None: ...
    class Float(java.awt.geom.RoundRectangle2D, java.io.Serializable):
        x: float = ...
        y: float = ...
        width: float = ...
        height: float = ...
        arcwidth: float = ...
        archeight: float = ...
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float): ...
        def getArcHeight(self) -> float: ...
        def getArcWidth(self) -> float: ...
        def getBounds2D(self) -> Rectangle2D: ...
        def getHeight(self) -> float: ...
        def getWidth(self) -> float: ...
        def getX(self) -> float: ...
        def getY(self) -> float: ...
        def isEmpty(self) -> bool: ...
        @typing.overload
        def setRoundRect(self, double: float, double2: float, double3: float, double4: float, double5: float, double6: float) -> None: ...
        @typing.overload
        def setRoundRect(self, float: float, float2: float, float3: float, float4: float, float5: float, float6: float) -> None: ...
        @typing.overload
        def setRoundRect(self, roundRectangle2D: 'RoundRectangle2D') -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.geom")``.

    AffineTransform: typing.Type[AffineTransform]
    Arc2D: typing.Type[Arc2D]
    Area: typing.Type[Area]
    CubicCurve2D: typing.Type[CubicCurve2D]
    Dimension2D: typing.Type[Dimension2D]
    Ellipse2D: typing.Type[Ellipse2D]
    FlatteningPathIterator: typing.Type[FlatteningPathIterator]
    GeneralPath: typing.Type[GeneralPath]
    IllegalPathStateException: typing.Type[IllegalPathStateException]
    Line2D: typing.Type[Line2D]
    NoninvertibleTransformException: typing.Type[NoninvertibleTransformException]
    Path2D: typing.Type[Path2D]
    PathIterator: typing.Type[PathIterator]
    Point2D: typing.Type[Point2D]
    QuadCurve2D: typing.Type[QuadCurve2D]
    Rectangle2D: typing.Type[Rectangle2D]
    RectangularShape: typing.Type[RectangularShape]
    RoundRectangle2D: typing.Type[RoundRectangle2D]



import java.io
import java.lang
import java.rmi
import java.rmi.server
import java.util
import typing



class Activatable(java.rmi.server.RemoteServer):
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote, activationID: 'ActivationID', int: int) -> java.rmi.Remote: ...
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote, activationID: 'ActivationID', int: int, rMIClientSocketFactory: java.rmi.server.RMIClientSocketFactory, rMIServerSocketFactory: java.rmi.server.RMIServerSocketFactory) -> java.rmi.Remote: ...
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote, string: str, marshalledObject: java.rmi.MarshalledObject[typing.Any], boolean: bool, int: int) -> 'ActivationID': ...
    @typing.overload
    @staticmethod
    def exportObject(remote: java.rmi.Remote, string: str, marshalledObject: java.rmi.MarshalledObject[typing.Any], boolean: bool, int: int, rMIClientSocketFactory: java.rmi.server.RMIClientSocketFactory, rMIServerSocketFactory: java.rmi.server.RMIServerSocketFactory) -> 'ActivationID': ...
    @staticmethod
    def inactive(activationID: 'ActivationID') -> bool: ...
    @staticmethod
    def register(activationDesc: 'ActivationDesc') -> java.rmi.Remote: ...
    @staticmethod
    def unexportObject(remote: java.rmi.Remote, boolean: bool) -> bool: ...
    @staticmethod
    def unregister(activationID: 'ActivationID') -> None: ...

class ActivateFailedException(java.rmi.RemoteException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, exception: java.lang.Exception): ...

class ActivationDesc(java.io.Serializable):
    @typing.overload
    def __init__(self, string: str, string2: str, marshalledObject: java.rmi.MarshalledObject[typing.Any]): ...
    @typing.overload
    def __init__(self, string: str, string2: str, marshalledObject: java.rmi.MarshalledObject[typing.Any], boolean: bool): ...
    @typing.overload
    def __init__(self, activationGroupID: 'ActivationGroupID', string: str, string2: str, marshalledObject: java.rmi.MarshalledObject[typing.Any]): ...
    @typing.overload
    def __init__(self, activationGroupID: 'ActivationGroupID', string: str, string2: str, marshalledObject: java.rmi.MarshalledObject[typing.Any], boolean: bool): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getClassName(self) -> str: ...
    def getData(self) -> java.rmi.MarshalledObject[typing.Any]: ...
    def getGroupID(self) -> 'ActivationGroupID': ...
    def getLocation(self) -> str: ...
    def getRestartMode(self) -> bool: ...
    def hashCode(self) -> int: ...

class ActivationException(java.lang.Exception):
    detail: java.lang.Throwable = ...
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    def getCause(self) -> java.lang.Throwable: ...
    def getMessage(self) -> str: ...

class ActivationGroupDesc(java.io.Serializable):
    @typing.overload
    def __init__(self, string: str, string2: str, marshalledObject: java.rmi.MarshalledObject[typing.Any], properties: java.util.Properties, commandEnvironment: 'ActivationGroupDesc.CommandEnvironment'): ...
    @typing.overload
    def __init__(self, properties: java.util.Properties, commandEnvironment: 'ActivationGroupDesc.CommandEnvironment'): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getClassName(self) -> str: ...
    def getCommandEnvironment(self) -> 'ActivationGroupDesc.CommandEnvironment': ...
    def getData(self) -> java.rmi.MarshalledObject[typing.Any]: ...
    def getLocation(self) -> str: ...
    def getPropertyOverrides(self) -> java.util.Properties: ...
    def hashCode(self) -> int: ...
    class CommandEnvironment(java.io.Serializable):
        def __init__(self, string: str, stringArray: typing.List[str]): ...
        def equals(self, object: typing.Any) -> bool: ...
        def getCommandOptions(self) -> typing.List[str]: ...
        def getCommandPath(self) -> str: ...
        def hashCode(self) -> int: ...

class ActivationGroupID(java.io.Serializable):
    def __init__(self, activationSystem: 'ActivationSystem'): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getSystem(self) -> 'ActivationSystem': ...
    def hashCode(self) -> int: ...

class ActivationID(java.io.Serializable):
    def __init__(self, activator: 'Activator'): ...
    def activate(self, boolean: bool) -> java.rmi.Remote: ...
    def equals(self, object: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...

class ActivationInstantiator(java.rmi.Remote):
    def newInstance(self, activationID: ActivationID, activationDesc: ActivationDesc) -> java.rmi.MarshalledObject[java.rmi.Remote]: ...

class ActivationMonitor(java.rmi.Remote):
    def activeObject(self, activationID: ActivationID, marshalledObject: java.rmi.MarshalledObject[java.rmi.Remote]) -> None: ...
    def inactiveGroup(self, activationGroupID: ActivationGroupID, long: int) -> None: ...
    def inactiveObject(self, activationID: ActivationID) -> None: ...

class ActivationSystem(java.rmi.Remote):
    SYSTEM_PORT: typing.ClassVar[int] = ...
    def activeGroup(self, activationGroupID: ActivationGroupID, activationInstantiator: ActivationInstantiator, long: int) -> ActivationMonitor: ...
    def getActivationDesc(self, activationID: ActivationID) -> ActivationDesc: ...
    def getActivationGroupDesc(self, activationGroupID: ActivationGroupID) -> ActivationGroupDesc: ...
    def registerGroup(self, activationGroupDesc: ActivationGroupDesc) -> ActivationGroupID: ...
    def registerObject(self, activationDesc: ActivationDesc) -> ActivationID: ...
    def setActivationDesc(self, activationID: ActivationID, activationDesc: ActivationDesc) -> ActivationDesc: ...
    def setActivationGroupDesc(self, activationGroupID: ActivationGroupID, activationGroupDesc: ActivationGroupDesc) -> ActivationGroupDesc: ...
    def shutdown(self) -> None: ...
    def unregisterGroup(self, activationGroupID: ActivationGroupID) -> None: ...
    def unregisterObject(self, activationID: ActivationID) -> None: ...

class Activator(java.rmi.Remote):
    def activate(self, activationID: ActivationID, boolean: bool) -> java.rmi.MarshalledObject[java.rmi.Remote]: ...

class ActivationGroup(java.rmi.server.UnicastRemoteObject, ActivationInstantiator):
    def activeObject(self, activationID: ActivationID, remote: java.rmi.Remote) -> None: ...
    @staticmethod
    def createGroup(activationGroupID: ActivationGroupID, activationGroupDesc: ActivationGroupDesc, long: int) -> 'ActivationGroup': ...
    @staticmethod
    def currentGroupID() -> ActivationGroupID: ...
    @staticmethod
    def getSystem() -> ActivationSystem: ...
    def inactiveObject(self, activationID: ActivationID) -> bool: ...
    @staticmethod
    def setSystem(activationSystem: ActivationSystem) -> None: ...

class ActivationGroup_Stub(java.rmi.server.RemoteStub, ActivationInstantiator, java.rmi.Remote):
    def __init__(self, remoteRef: java.rmi.server.RemoteRef): ...
    def newInstance(self, activationID: ActivationID, activationDesc: ActivationDesc) -> java.rmi.MarshalledObject: ...

class UnknownGroupException(ActivationException):
    def __init__(self, string: str): ...

class UnknownObjectException(ActivationException):
    def __init__(self, string: str): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.rmi.activation")``.

    Activatable: typing.Type[Activatable]
    ActivateFailedException: typing.Type[ActivateFailedException]
    ActivationDesc: typing.Type[ActivationDesc]
    ActivationException: typing.Type[ActivationException]
    ActivationGroup: typing.Type[ActivationGroup]
    ActivationGroupDesc: typing.Type[ActivationGroupDesc]
    ActivationGroupID: typing.Type[ActivationGroupID]
    ActivationGroup_Stub: typing.Type[ActivationGroup_Stub]
    ActivationID: typing.Type[ActivationID]
    ActivationInstantiator: typing.Type[ActivationInstantiator]
    ActivationMonitor: typing.Type[ActivationMonitor]
    ActivationSystem: typing.Type[ActivationSystem]
    Activator: typing.Type[Activator]
    UnknownGroupException: typing.Type[UnknownGroupException]
    UnknownObjectException: typing.Type[UnknownObjectException]



import java.awt
import java.awt.datatransfer
import java.awt.dnd.peer
import java.awt.event
import java.io
import java.lang
import java.util
import typing



class Autoscroll:
    def autoscroll(self, point: java.awt.Point) -> None: ...
    def getAutoscrollInsets(self) -> java.awt.Insets: ...

class DnDConstants:
    ACTION_NONE: typing.ClassVar[int] = ...
    ACTION_COPY: typing.ClassVar[int] = ...
    ACTION_MOVE: typing.ClassVar[int] = ...
    ACTION_COPY_OR_MOVE: typing.ClassVar[int] = ...
    ACTION_LINK: typing.ClassVar[int] = ...
    ACTION_REFERENCE: typing.ClassVar[int] = ...

class DragGestureEvent(java.util.EventObject):
    def __init__(self, dragGestureRecognizer: 'DragGestureRecognizer', int: int, point: java.awt.Point, list: java.util.List[java.awt.event.InputEvent]): ...
    def getComponent(self) -> java.awt.Component: ...
    def getDragAction(self) -> int: ...
    def getDragOrigin(self) -> java.awt.Point: ...
    def getDragSource(self) -> 'DragSource': ...
    def getSourceAsDragGestureRecognizer(self) -> 'DragGestureRecognizer': ...
    def getTriggerEvent(self) -> java.awt.event.InputEvent: ...
    def iterator(self) -> java.util.Iterator[java.awt.event.InputEvent]: ...
    @typing.overload
    def startDrag(self, cursor: java.awt.Cursor, image: java.awt.Image, point: java.awt.Point, transferable: java.awt.datatransfer.Transferable, dragSourceListener: 'DragSourceListener') -> None: ...
    @typing.overload
    def startDrag(self, cursor: java.awt.Cursor, transferable: java.awt.datatransfer.Transferable) -> None: ...
    @typing.overload
    def startDrag(self, cursor: java.awt.Cursor, transferable: java.awt.datatransfer.Transferable, dragSourceListener: 'DragSourceListener') -> None: ...
    @typing.overload
    def toArray(self) -> typing.List[typing.Any]: ...
    @typing.overload
    def toArray(self, objectArray: typing.List[typing.Any]) -> typing.List[typing.Any]: ...

class DragGestureListener(java.util.EventListener):
    def dragGestureRecognized(self, dragGestureEvent: DragGestureEvent) -> None: ...

class DragGestureRecognizer(java.io.Serializable):
    def addDragGestureListener(self, dragGestureListener: DragGestureListener) -> None: ...
    def getComponent(self) -> java.awt.Component: ...
    def getDragSource(self) -> 'DragSource': ...
    def getSourceActions(self) -> int: ...
    def getTriggerEvent(self) -> java.awt.event.InputEvent: ...
    def removeDragGestureListener(self, dragGestureListener: DragGestureListener) -> None: ...
    def resetRecognizer(self) -> None: ...
    def setComponent(self, component: java.awt.Component) -> None: ...
    def setSourceActions(self, int: int) -> None: ...

class DragSource(java.io.Serializable):
    DefaultCopyDrop: typing.ClassVar[java.awt.Cursor] = ...
    DefaultMoveDrop: typing.ClassVar[java.awt.Cursor] = ...
    DefaultLinkDrop: typing.ClassVar[java.awt.Cursor] = ...
    DefaultCopyNoDrop: typing.ClassVar[java.awt.Cursor] = ...
    DefaultMoveNoDrop: typing.ClassVar[java.awt.Cursor] = ...
    DefaultLinkNoDrop: typing.ClassVar[java.awt.Cursor] = ...
    def __init__(self): ...
    def addDragSourceListener(self, dragSourceListener: 'DragSourceListener') -> None: ...
    def addDragSourceMotionListener(self, dragSourceMotionListener: 'DragSourceMotionListener') -> None: ...
    def createDefaultDragGestureRecognizer(self, component: java.awt.Component, int: int, dragGestureListener: DragGestureListener) -> DragGestureRecognizer: ...
    _createDragGestureRecognizer__T = typing.TypeVar('_createDragGestureRecognizer__T', bound=DragGestureRecognizer)  # <T>
    def createDragGestureRecognizer(self, class_: typing.Type[_createDragGestureRecognizer__T], component: java.awt.Component, int: int, dragGestureListener: DragGestureListener) -> _createDragGestureRecognizer__T: ...
    @staticmethod
    def getDefaultDragSource() -> 'DragSource': ...
    def getDragSourceListeners(self) -> typing.List['DragSourceListener']: ...
    def getDragSourceMotionListeners(self) -> typing.List['DragSourceMotionListener']: ...
    @staticmethod
    def getDragThreshold() -> int: ...
    def getFlavorMap(self) -> java.awt.datatransfer.FlavorMap: ...
    _getListeners__T = typing.TypeVar('_getListeners__T', bound=java.util.EventListener)  # <T>
    def getListeners(self, class_: typing.Type[_getListeners__T]) -> typing.List[_getListeners__T]: ...
    @staticmethod
    def isDragImageSupported() -> bool: ...
    def removeDragSourceListener(self, dragSourceListener: 'DragSourceListener') -> None: ...
    def removeDragSourceMotionListener(self, dragSourceMotionListener: 'DragSourceMotionListener') -> None: ...
    @typing.overload
    def startDrag(self, dragGestureEvent: DragGestureEvent, cursor: java.awt.Cursor, image: java.awt.Image, point: java.awt.Point, transferable: java.awt.datatransfer.Transferable, dragSourceListener: 'DragSourceListener') -> None: ...
    @typing.overload
    def startDrag(self, dragGestureEvent: DragGestureEvent, cursor: java.awt.Cursor, image: java.awt.Image, point: java.awt.Point, transferable: java.awt.datatransfer.Transferable, dragSourceListener: 'DragSourceListener', flavorMap: java.awt.datatransfer.FlavorMap) -> None: ...
    @typing.overload
    def startDrag(self, dragGestureEvent: DragGestureEvent, cursor: java.awt.Cursor, transferable: java.awt.datatransfer.Transferable, dragSourceListener: 'DragSourceListener') -> None: ...
    @typing.overload
    def startDrag(self, dragGestureEvent: DragGestureEvent, cursor: java.awt.Cursor, transferable: java.awt.datatransfer.Transferable, dragSourceListener: 'DragSourceListener', flavorMap: java.awt.datatransfer.FlavorMap) -> None: ...

class DragSourceEvent(java.util.EventObject):
    @typing.overload
    def __init__(self, dragSourceContext: 'DragSourceContext'): ...
    @typing.overload
    def __init__(self, dragSourceContext: 'DragSourceContext', int: int, int2: int): ...
    def getDragSourceContext(self) -> 'DragSourceContext': ...
    def getLocation(self) -> java.awt.Point: ...
    def getX(self) -> int: ...
    def getY(self) -> int: ...

class DragSourceListener(java.util.EventListener):
    def dragDropEnd(self, dragSourceDropEvent: 'DragSourceDropEvent') -> None: ...
    def dragEnter(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def dragExit(self, dragSourceEvent: DragSourceEvent) -> None: ...
    def dragOver(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def dropActionChanged(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...

class DragSourceMotionListener(java.util.EventListener):
    def dragMouseMoved(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...

class DropTargetContext(java.io.Serializable):
    def dropComplete(self, boolean: bool) -> None: ...
    def getComponent(self) -> java.awt.Component: ...
    def getDropTarget(self) -> 'DropTarget': ...

class DropTargetEvent(java.util.EventObject):
    def __init__(self, dropTargetContext: DropTargetContext): ...
    def getDropTargetContext(self) -> DropTargetContext: ...

class DropTargetListener(java.util.EventListener):
    def dragEnter(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...
    def dragExit(self, dropTargetEvent: DropTargetEvent) -> None: ...
    def dragOver(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...
    def drop(self, dropTargetDropEvent: 'DropTargetDropEvent') -> None: ...
    def dropActionChanged(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...

class InvalidDnDOperationException(java.lang.IllegalStateException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class DragSourceAdapter(DragSourceListener, DragSourceMotionListener):
    def __init__(self): ...
    def dragDropEnd(self, dragSourceDropEvent: 'DragSourceDropEvent') -> None: ...
    def dragEnter(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def dragExit(self, dragSourceEvent: DragSourceEvent) -> None: ...
    def dragMouseMoved(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def dragOver(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def dropActionChanged(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...

class DragSourceContext(DragSourceListener, DragSourceMotionListener, java.io.Serializable):
    def __init__(self, dragGestureEvent: DragGestureEvent, cursor: java.awt.Cursor, image: java.awt.Image, point: java.awt.Point, transferable: java.awt.datatransfer.Transferable, dragSourceListener: DragSourceListener): ...
    def addDragSourceListener(self, dragSourceListener: DragSourceListener) -> None: ...
    def dragDropEnd(self, dragSourceDropEvent: 'DragSourceDropEvent') -> None: ...
    def dragEnter(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def dragExit(self, dragSourceEvent: DragSourceEvent) -> None: ...
    def dragMouseMoved(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def dragOver(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def dropActionChanged(self, dragSourceDragEvent: 'DragSourceDragEvent') -> None: ...
    def getComponent(self) -> java.awt.Component: ...
    def getCursor(self) -> java.awt.Cursor: ...
    def getDragSource(self) -> DragSource: ...
    def getSourceActions(self) -> int: ...
    def getTransferable(self) -> java.awt.datatransfer.Transferable: ...
    def getTrigger(self) -> DragGestureEvent: ...
    def removeDragSourceListener(self, dragSourceListener: DragSourceListener) -> None: ...
    def setCursor(self, cursor: java.awt.Cursor) -> None: ...
    def transferablesFlavorsChanged(self) -> None: ...

class DragSourceDragEvent(DragSourceEvent):
    @typing.overload
    def __init__(self, dragSourceContext: DragSourceContext, int: int, int2: int, int3: int): ...
    @typing.overload
    def __init__(self, dragSourceContext: DragSourceContext, int: int, int2: int, int3: int, int4: int, int5: int): ...
    def getDropAction(self) -> int: ...
    def getGestureModifiers(self) -> int: ...
    def getGestureModifiersEx(self) -> int: ...
    def getTargetActions(self) -> int: ...
    def getUserAction(self) -> int: ...

class DragSourceDropEvent(DragSourceEvent):
    @typing.overload
    def __init__(self, dragSourceContext: DragSourceContext): ...
    @typing.overload
    def __init__(self, dragSourceContext: DragSourceContext, int: int, boolean: bool): ...
    @typing.overload
    def __init__(self, dragSourceContext: DragSourceContext, int: int, boolean: bool, int2: int, int3: int): ...
    def getDropAction(self) -> int: ...
    def getDropSuccess(self) -> bool: ...

class DropTarget(DropTargetListener, java.io.Serializable):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, component: java.awt.Component, int: int, dropTargetListener: DropTargetListener): ...
    @typing.overload
    def __init__(self, component: java.awt.Component, int: int, dropTargetListener: DropTargetListener, boolean: bool): ...
    @typing.overload
    def __init__(self, component: java.awt.Component, int: int, dropTargetListener: DropTargetListener, boolean: bool, flavorMap: java.awt.datatransfer.FlavorMap): ...
    @typing.overload
    def __init__(self, component: java.awt.Component, dropTargetListener: DropTargetListener): ...
    def addDropTargetListener(self, dropTargetListener: DropTargetListener) -> None: ...
    def addNotify(self) -> None: ...
    def dragEnter(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...
    def dragExit(self, dropTargetEvent: DropTargetEvent) -> None: ...
    def dragOver(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...
    def drop(self, dropTargetDropEvent: 'DropTargetDropEvent') -> None: ...
    def dropActionChanged(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...
    def getComponent(self) -> java.awt.Component: ...
    def getDefaultActions(self) -> int: ...
    def getDropTargetContext(self) -> DropTargetContext: ...
    def getFlavorMap(self) -> java.awt.datatransfer.FlavorMap: ...
    def isActive(self) -> bool: ...
    def removeDropTargetListener(self, dropTargetListener: DropTargetListener) -> None: ...
    def removeNotify(self) -> None: ...
    def setActive(self, boolean: bool) -> None: ...
    def setComponent(self, component: java.awt.Component) -> None: ...
    def setDefaultActions(self, int: int) -> None: ...
    def setFlavorMap(self, flavorMap: java.awt.datatransfer.FlavorMap) -> None: ...

class DropTargetAdapter(DropTargetListener):
    def __init__(self): ...
    def dragEnter(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...
    def dragExit(self, dropTargetEvent: DropTargetEvent) -> None: ...
    def dragOver(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...
    def dropActionChanged(self, dropTargetDragEvent: 'DropTargetDragEvent') -> None: ...

class DropTargetDragEvent(DropTargetEvent):
    def __init__(self, dropTargetContext: DropTargetContext, point: java.awt.Point, int: int, int2: int): ...
    def acceptDrag(self, int: int) -> None: ...
    def getCurrentDataFlavors(self) -> typing.List[java.awt.datatransfer.DataFlavor]: ...
    def getCurrentDataFlavorsAsList(self) -> java.util.List[java.awt.datatransfer.DataFlavor]: ...
    def getDropAction(self) -> int: ...
    def getLocation(self) -> java.awt.Point: ...
    def getSourceActions(self) -> int: ...
    def getTransferable(self) -> java.awt.datatransfer.Transferable: ...
    def isDataFlavorSupported(self, dataFlavor: java.awt.datatransfer.DataFlavor) -> bool: ...
    def rejectDrag(self) -> None: ...

class DropTargetDropEvent(DropTargetEvent):
    @typing.overload
    def __init__(self, dropTargetContext: DropTargetContext, point: java.awt.Point, int: int, int2: int): ...
    @typing.overload
    def __init__(self, dropTargetContext: DropTargetContext, point: java.awt.Point, int: int, int2: int, boolean: bool): ...
    def acceptDrop(self, int: int) -> None: ...
    def dropComplete(self, boolean: bool) -> None: ...
    def getCurrentDataFlavors(self) -> typing.List[java.awt.datatransfer.DataFlavor]: ...
    def getCurrentDataFlavorsAsList(self) -> java.util.List[java.awt.datatransfer.DataFlavor]: ...
    def getDropAction(self) -> int: ...
    def getLocation(self) -> java.awt.Point: ...
    def getSourceActions(self) -> int: ...
    def getTransferable(self) -> java.awt.datatransfer.Transferable: ...
    def isDataFlavorSupported(self, dataFlavor: java.awt.datatransfer.DataFlavor) -> bool: ...
    def isLocalTransfer(self) -> bool: ...
    def rejectDrop(self) -> None: ...

class MouseDragGestureRecognizer(DragGestureRecognizer, java.awt.event.MouseListener, java.awt.event.MouseMotionListener):
    def mouseClicked(self, mouseEvent: java.awt.event.MouseEvent) -> None: ...
    def mouseDragged(self, mouseEvent: java.awt.event.MouseEvent) -> None: ...
    def mouseEntered(self, mouseEvent: java.awt.event.MouseEvent) -> None: ...
    def mouseExited(self, mouseEvent: java.awt.event.MouseEvent) -> None: ...
    def mouseMoved(self, mouseEvent: java.awt.event.MouseEvent) -> None: ...
    def mousePressed(self, mouseEvent: java.awt.event.MouseEvent) -> None: ...
    def mouseReleased(self, mouseEvent: java.awt.event.MouseEvent) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.dnd")``.

    Autoscroll: typing.Type[Autoscroll]
    DnDConstants: typing.Type[DnDConstants]
    DragGestureEvent: typing.Type[DragGestureEvent]
    DragGestureListener: typing.Type[DragGestureListener]
    DragGestureRecognizer: typing.Type[DragGestureRecognizer]
    DragSource: typing.Type[DragSource]
    DragSourceAdapter: typing.Type[DragSourceAdapter]
    DragSourceContext: typing.Type[DragSourceContext]
    DragSourceDragEvent: typing.Type[DragSourceDragEvent]
    DragSourceDropEvent: typing.Type[DragSourceDropEvent]
    DragSourceEvent: typing.Type[DragSourceEvent]
    DragSourceListener: typing.Type[DragSourceListener]
    DragSourceMotionListener: typing.Type[DragSourceMotionListener]
    DropTarget: typing.Type[DropTarget]
    DropTargetAdapter: typing.Type[DropTargetAdapter]
    DropTargetContext: typing.Type[DropTargetContext]
    DropTargetDragEvent: typing.Type[DropTargetDragEvent]
    DropTargetDropEvent: typing.Type[DropTargetDropEvent]
    DropTargetEvent: typing.Type[DropTargetEvent]
    DropTargetListener: typing.Type[DropTargetListener]
    InvalidDnDOperationException: typing.Type[InvalidDnDOperationException]
    MouseDragGestureRecognizer: typing.Type[MouseDragGestureRecognizer]
    peer: java.awt.dnd.peer.__module_protocol__



import java.io
import java.lang
import typing



class CMMException(java.lang.RuntimeException):
    def __init__(self, string: str): ...

class ColorSpace(java.io.Serializable):
    TYPE_XYZ: typing.ClassVar[int] = ...
    TYPE_Lab: typing.ClassVar[int] = ...
    TYPE_Luv: typing.ClassVar[int] = ...
    TYPE_YCbCr: typing.ClassVar[int] = ...
    TYPE_Yxy: typing.ClassVar[int] = ...
    TYPE_RGB: typing.ClassVar[int] = ...
    TYPE_GRAY: typing.ClassVar[int] = ...
    TYPE_HSV: typing.ClassVar[int] = ...
    TYPE_HLS: typing.ClassVar[int] = ...
    TYPE_CMYK: typing.ClassVar[int] = ...
    TYPE_CMY: typing.ClassVar[int] = ...
    TYPE_2CLR: typing.ClassVar[int] = ...
    TYPE_3CLR: typing.ClassVar[int] = ...
    TYPE_4CLR: typing.ClassVar[int] = ...
    TYPE_5CLR: typing.ClassVar[int] = ...
    TYPE_6CLR: typing.ClassVar[int] = ...
    TYPE_7CLR: typing.ClassVar[int] = ...
    TYPE_8CLR: typing.ClassVar[int] = ...
    TYPE_9CLR: typing.ClassVar[int] = ...
    TYPE_ACLR: typing.ClassVar[int] = ...
    TYPE_BCLR: typing.ClassVar[int] = ...
    TYPE_CCLR: typing.ClassVar[int] = ...
    TYPE_DCLR: typing.ClassVar[int] = ...
    TYPE_ECLR: typing.ClassVar[int] = ...
    TYPE_FCLR: typing.ClassVar[int] = ...
    CS_sRGB: typing.ClassVar[int] = ...
    CS_LINEAR_RGB: typing.ClassVar[int] = ...
    CS_CIEXYZ: typing.ClassVar[int] = ...
    CS_PYCC: typing.ClassVar[int] = ...
    CS_GRAY: typing.ClassVar[int] = ...
    def fromCIEXYZ(self, floatArray: typing.List[float]) -> typing.List[float]: ...
    def fromRGB(self, floatArray: typing.List[float]) -> typing.List[float]: ...
    @staticmethod
    def getInstance(int: int) -> 'ColorSpace': ...
    def getMaxValue(self, int: int) -> float: ...
    def getMinValue(self, int: int) -> float: ...
    def getName(self, int: int) -> str: ...
    def getNumComponents(self) -> int: ...
    def getType(self) -> int: ...
    def isCS_sRGB(self) -> bool: ...
    def toCIEXYZ(self, floatArray: typing.List[float]) -> typing.List[float]: ...
    def toRGB(self, floatArray: typing.List[float]) -> typing.List[float]: ...

class ICC_Profile(java.io.Serializable):
    CLASS_INPUT: typing.ClassVar[int] = ...
    CLASS_DISPLAY: typing.ClassVar[int] = ...
    CLASS_OUTPUT: typing.ClassVar[int] = ...
    CLASS_DEVICELINK: typing.ClassVar[int] = ...
    CLASS_COLORSPACECONVERSION: typing.ClassVar[int] = ...
    CLASS_ABSTRACT: typing.ClassVar[int] = ...
    CLASS_NAMEDCOLOR: typing.ClassVar[int] = ...
    icSigXYZData: typing.ClassVar[int] = ...
    icSigLabData: typing.ClassVar[int] = ...
    icSigLuvData: typing.ClassVar[int] = ...
    icSigYCbCrData: typing.ClassVar[int] = ...
    icSigYxyData: typing.ClassVar[int] = ...
    icSigRgbData: typing.ClassVar[int] = ...
    icSigGrayData: typing.ClassVar[int] = ...
    icSigHsvData: typing.ClassVar[int] = ...
    icSigHlsData: typing.ClassVar[int] = ...
    icSigCmykData: typing.ClassVar[int] = ...
    icSigCmyData: typing.ClassVar[int] = ...
    icSigSpace2CLR: typing.ClassVar[int] = ...
    icSigSpace3CLR: typing.ClassVar[int] = ...
    icSigSpace4CLR: typing.ClassVar[int] = ...
    icSigSpace5CLR: typing.ClassVar[int] = ...
    icSigSpace6CLR: typing.ClassVar[int] = ...
    icSigSpace7CLR: typing.ClassVar[int] = ...
    icSigSpace8CLR: typing.ClassVar[int] = ...
    icSigSpace9CLR: typing.ClassVar[int] = ...
    icSigSpaceACLR: typing.ClassVar[int] = ...
    icSigSpaceBCLR: typing.ClassVar[int] = ...
    icSigSpaceCCLR: typing.ClassVar[int] = ...
    icSigSpaceDCLR: typing.ClassVar[int] = ...
    icSigSpaceECLR: typing.ClassVar[int] = ...
    icSigSpaceFCLR: typing.ClassVar[int] = ...
    icSigInputClass: typing.ClassVar[int] = ...
    icSigDisplayClass: typing.ClassVar[int] = ...
    icSigOutputClass: typing.ClassVar[int] = ...
    icSigLinkClass: typing.ClassVar[int] = ...
    icSigAbstractClass: typing.ClassVar[int] = ...
    icSigColorSpaceClass: typing.ClassVar[int] = ...
    icSigNamedColorClass: typing.ClassVar[int] = ...
    icPerceptual: typing.ClassVar[int] = ...
    icRelativeColorimetric: typing.ClassVar[int] = ...
    icMediaRelativeColorimetric: typing.ClassVar[int] = ...
    icSaturation: typing.ClassVar[int] = ...
    icAbsoluteColorimetric: typing.ClassVar[int] = ...
    icICCAbsoluteColorimetric: typing.ClassVar[int] = ...
    icSigHead: typing.ClassVar[int] = ...
    icSigAToB0Tag: typing.ClassVar[int] = ...
    icSigAToB1Tag: typing.ClassVar[int] = ...
    icSigAToB2Tag: typing.ClassVar[int] = ...
    icSigBlueColorantTag: typing.ClassVar[int] = ...
    icSigBlueMatrixColumnTag: typing.ClassVar[int] = ...
    icSigBlueTRCTag: typing.ClassVar[int] = ...
    icSigBToA0Tag: typing.ClassVar[int] = ...
    icSigBToA1Tag: typing.ClassVar[int] = ...
    icSigBToA2Tag: typing.ClassVar[int] = ...
    icSigCalibrationDateTimeTag: typing.ClassVar[int] = ...
    icSigCharTargetTag: typing.ClassVar[int] = ...
    icSigCopyrightTag: typing.ClassVar[int] = ...
    icSigCrdInfoTag: typing.ClassVar[int] = ...
    icSigDeviceMfgDescTag: typing.ClassVar[int] = ...
    icSigDeviceModelDescTag: typing.ClassVar[int] = ...
    icSigDeviceSettingsTag: typing.ClassVar[int] = ...
    icSigGamutTag: typing.ClassVar[int] = ...
    icSigGrayTRCTag: typing.ClassVar[int] = ...
    icSigGreenColorantTag: typing.ClassVar[int] = ...
    icSigGreenMatrixColumnTag: typing.ClassVar[int] = ...
    icSigGreenTRCTag: typing.ClassVar[int] = ...
    icSigLuminanceTag: typing.ClassVar[int] = ...
    icSigMeasurementTag: typing.ClassVar[int] = ...
    icSigMediaBlackPointTag: typing.ClassVar[int] = ...
    icSigMediaWhitePointTag: typing.ClassVar[int] = ...
    icSigNamedColor2Tag: typing.ClassVar[int] = ...
    icSigOutputResponseTag: typing.ClassVar[int] = ...
    icSigPreview0Tag: typing.ClassVar[int] = ...
    icSigPreview1Tag: typing.ClassVar[int] = ...
    icSigPreview2Tag: typing.ClassVar[int] = ...
    icSigProfileDescriptionTag: typing.ClassVar[int] = ...
    icSigProfileSequenceDescTag: typing.ClassVar[int] = ...
    icSigPs2CRD0Tag: typing.ClassVar[int] = ...
    icSigPs2CRD1Tag: typing.ClassVar[int] = ...
    icSigPs2CRD2Tag: typing.ClassVar[int] = ...
    icSigPs2CRD3Tag: typing.ClassVar[int] = ...
    icSigPs2CSATag: typing.ClassVar[int] = ...
    icSigPs2RenderingIntentTag: typing.ClassVar[int] = ...
    icSigRedColorantTag: typing.ClassVar[int] = ...
    icSigRedMatrixColumnTag: typing.ClassVar[int] = ...
    icSigRedTRCTag: typing.ClassVar[int] = ...
    icSigScreeningDescTag: typing.ClassVar[int] = ...
    icSigScreeningTag: typing.ClassVar[int] = ...
    icSigTechnologyTag: typing.ClassVar[int] = ...
    icSigUcrBgTag: typing.ClassVar[int] = ...
    icSigViewingCondDescTag: typing.ClassVar[int] = ...
    icSigViewingConditionsTag: typing.ClassVar[int] = ...
    icSigChromaticityTag: typing.ClassVar[int] = ...
    icSigChromaticAdaptationTag: typing.ClassVar[int] = ...
    icSigColorantOrderTag: typing.ClassVar[int] = ...
    icSigColorantTableTag: typing.ClassVar[int] = ...
    icHdrSize: typing.ClassVar[int] = ...
    icHdrCmmId: typing.ClassVar[int] = ...
    icHdrVersion: typing.ClassVar[int] = ...
    icHdrDeviceClass: typing.ClassVar[int] = ...
    icHdrColorSpace: typing.ClassVar[int] = ...
    icHdrPcs: typing.ClassVar[int] = ...
    icHdrDate: typing.ClassVar[int] = ...
    icHdrMagic: typing.ClassVar[int] = ...
    icHdrPlatform: typing.ClassVar[int] = ...
    icHdrFlags: typing.ClassVar[int] = ...
    icHdrManufacturer: typing.ClassVar[int] = ...
    icHdrModel: typing.ClassVar[int] = ...
    icHdrAttributes: typing.ClassVar[int] = ...
    icHdrRenderingIntent: typing.ClassVar[int] = ...
    icHdrIlluminant: typing.ClassVar[int] = ...
    icHdrCreator: typing.ClassVar[int] = ...
    icHdrProfileID: typing.ClassVar[int] = ...
    icTagType: typing.ClassVar[int] = ...
    icTagReserved: typing.ClassVar[int] = ...
    icCurveCount: typing.ClassVar[int] = ...
    icCurveData: typing.ClassVar[int] = ...
    icXYZNumberX: typing.ClassVar[int] = ...
    def getColorSpaceType(self) -> int: ...
    @typing.overload
    def getData(self) -> typing.List[int]: ...
    @typing.overload
    def getData(self, int: int) -> typing.List[int]: ...
    @typing.overload
    @staticmethod
    def getInstance(byteArray: typing.List[int]) -> 'ICC_Profile': ...
    @typing.overload
    @staticmethod
    def getInstance(int: int) -> 'ICC_Profile': ...
    @typing.overload
    @staticmethod
    def getInstance(inputStream: java.io.InputStream) -> 'ICC_Profile': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'ICC_Profile': ...
    def getMajorVersion(self) -> int: ...
    def getMinorVersion(self) -> int: ...
    def getNumComponents(self) -> int: ...
    def getPCSType(self) -> int: ...
    def getProfileClass(self) -> int: ...
    def setData(self, int: int, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def write(self, outputStream: java.io.OutputStream) -> None: ...
    @typing.overload
    def write(self, string: str) -> None: ...

class ProfileDataException(java.lang.RuntimeException):
    def __init__(self, string: str): ...

class ICC_ColorSpace(ColorSpace):
    def __init__(self, iCC_Profile: ICC_Profile): ...
    def fromCIEXYZ(self, floatArray: typing.List[float]) -> typing.List[float]: ...
    def fromRGB(self, floatArray: typing.List[float]) -> typing.List[float]: ...
    def getMaxValue(self, int: int) -> float: ...
    def getMinValue(self, int: int) -> float: ...
    def getProfile(self) -> ICC_Profile: ...
    def toCIEXYZ(self, floatArray: typing.List[float]) -> typing.List[float]: ...
    def toRGB(self, floatArray: typing.List[float]) -> typing.List[float]: ...

class ICC_ProfileGray(ICC_Profile):
    def getGamma(self) -> float: ...
    def getMediaWhitePoint(self) -> typing.List[float]: ...
    def getTRC(self) -> typing.List[int]: ...

class ICC_ProfileRGB(ICC_Profile):
    REDCOMPONENT: typing.ClassVar[int] = ...
    GREENCOMPONENT: typing.ClassVar[int] = ...
    BLUECOMPONENT: typing.ClassVar[int] = ...
    def getGamma(self, int: int) -> float: ...
    def getMatrix(self) -> typing.List[typing.List[float]]: ...
    def getMediaWhitePoint(self) -> typing.List[float]: ...
    def getTRC(self, int: int) -> typing.List[int]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.awt.color")``.

    CMMException: typing.Type[CMMException]
    ColorSpace: typing.Type[ColorSpace]
    ICC_ColorSpace: typing.Type[ICC_ColorSpace]
    ICC_Profile: typing.Type[ICC_Profile]
    ICC_ProfileGray: typing.Type[ICC_ProfileGray]
    ICC_ProfileRGB: typing.Type[ICC_ProfileRGB]
    ProfileDataException: typing.Type[ProfileDataException]



import com.google.gson
import com.google.gson.stream
import datetime
import java.lang
import java.net
import java.sql
import java.text
import java.time
import java.time.format
import java.util
import okhttp3
import org
import org.ergoplatform.explorer.client.auth
import org.ergoplatform.explorer.client.model
import retrofit2
import typing



class DefaultApi:
    def getApiV1AddressesP1BalanceConfirmed(self, string: typing.Union[java.lang.String, str], integer: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.Balance]: ...
    def getApiV1AddressesP1BalanceTotal(self, string: typing.Union[java.lang.String, str]) -> retrofit2.Call[org.ergoplatform.explorer.client.model.TotalBalance]: ...
    def getApiV1AddressesP1Transactions(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int, boolean: bool) -> retrofit2.Call[org.ergoplatform.explorer.client.model.Items[org.ergoplatform.explorer.client.model.TransactionInfo]]: ...
    def getApiV1Assets(self, integer: int, integer2: int, string: typing.Union[java.lang.String, str], boolean: bool) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1AssetsSearchBytokenid(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1Blocks(self, integer: int, integer2: int, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> retrofit2.Call[org.ergoplatform.explorer.client.model.Items[org.ergoplatform.explorer.client.model.BlockInfo]]: ...
    def getApiV1BlocksP1(self, string: typing.Union[java.lang.String, str]) -> retrofit2.Call[org.ergoplatform.explorer.client.model.BlockSummary]: ...
    def getApiV1BoxesByaddressP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1BoxesByergotreeP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1BoxesByergotreetemplatehashP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1BoxesByergotreetemplatehashP1Stream(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ListOutputInfo]: ...
    def getApiV1BoxesBytokenidP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1BoxesP1(self, string: typing.Union[java.lang.String, str]) -> retrofit2.Call[org.ergoplatform.explorer.client.model.OutputInfo]: ...
    def getApiV1BoxesUnspentByaddressP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int, string2: typing.Union[java.lang.String, str]) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1BoxesUnspentByergotreeP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1BoxesUnspentByergotreetemplatehashP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1BoxesUnspentByergotreetemplatehashP1Stream(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ListOutputInfo]: ...
    def getApiV1BoxesUnspentBylastepochsStream(self, integer: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ListOutputInfo]: ...
    def getApiV1BoxesUnspentBytokenidP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1BoxesUnspentStream(self, integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ListOutputInfo]: ...
    def getApiV1EpochsParams(self) -> retrofit2.Call[org.ergoplatform.explorer.client.model.EpochParameters]: ...
    def getApiV1MempoolTransactionsByaddressP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.Items[org.ergoplatform.explorer.client.model.TransactionInfo]]: ...
    def getApiV1Tokens(self, integer: int, integer2: int, string: typing.Union[java.lang.String, str], boolean: bool) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1TokensP1(self, string: typing.Union[java.lang.String, str]) -> retrofit2.Call[org.ergoplatform.explorer.client.model.TokenInfo]: ...
    def getApiV1TokensSearch(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1TransactionsByinputsscripttemplatehashP1(self, string: typing.Union[java.lang.String, str], integer: int, integer2: int, string2: typing.Union[java.lang.String, str]) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...
    def getApiV1TransactionsP1(self, string: typing.Union[java.lang.String, str]) -> retrofit2.Call[org.ergoplatform.explorer.client.model.TransactionInfo]: ...
    def postApiV1BoxesSearch(self, boxQuery: org.ergoplatform.explorer.client.model.BoxQuery, integer: int, integer2: int) -> retrofit2.Call[org.ergoplatform.explorer.client.model.ItemsA]: ...

class ExplorerApiClient:
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str]): ...
    @typing.overload
    def __init__(self, string: typing.Union[java.lang.String, str], proxy: java.net.Proxy): ...
    def configureFromOkClientBuilder(self, builder: okhttp3.OkHttpClient.Builder) -> None: ...
    def configureFromOkclient(self, okHttpClient: okhttp3.OkHttpClient) -> None: ...
    def createDefaultAdapter(self) -> None: ...
    _createService__S = typing.TypeVar('_createService__S')  # <S>
    def createService(self, class_: typing.Type[_createService__S]) -> _createService__S: ...
    def getAdapterBuilder(self) -> retrofit2.Retrofit.Builder: ...
    def getOkBuilder(self) -> okhttp3.OkHttpClient.Builder: ...
    def setAdapterBuilder(self, builder: retrofit2.Retrofit.Builder) -> 'ExplorerApiClient': ...
    def setDateFormat(self, dateFormat: java.text.DateFormat) -> 'ExplorerApiClient': ...
    def setLocalDateFormat(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'ExplorerApiClient': ...
    def setOffsetDateTimeFormat(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'ExplorerApiClient': ...
    def setSqlDateFormat(self, dateFormat: java.text.DateFormat) -> 'ExplorerApiClient': ...

class JSON:
    def __init__(self): ...
    @staticmethod
    def createGson() -> com.google.gson.GsonBuilder: ...
    def getGson(self) -> com.google.gson.Gson: ...
    def setDateFormat(self, dateFormat: java.text.DateFormat) -> 'JSON': ...
    def setGson(self, gson: com.google.gson.Gson) -> 'JSON': ...
    def setLocalDateFormat(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'JSON': ...
    def setOffsetDateTimeFormat(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> 'JSON': ...
    def setSqlDateFormat(self, dateFormat: java.text.DateFormat) -> 'JSON': ...
    class DateTypeAdapter(com.google.gson.TypeAdapter[java.util.Date]):
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, dateFormat: java.text.DateFormat): ...
        def read(self, jsonReader: com.google.gson.stream.JsonReader) -> java.util.Date: ...
        def setFormat(self, dateFormat: java.text.DateFormat) -> None: ...
        def write(self, jsonWriter: com.google.gson.stream.JsonWriter, date: java.util.Date) -> None: ...
    class LocalDateTypeAdapter(com.google.gson.TypeAdapter[java.time.LocalDate]):
        @typing.overload
        def __init__(self, jSON: 'JSON'): ...
        @typing.overload
        def __init__(self, jSON: 'JSON', dateTimeFormatter: java.time.format.DateTimeFormatter): ...
        def read(self, jsonReader: com.google.gson.stream.JsonReader) -> java.time.LocalDate: ...
        def setFormat(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> None: ...
        def write(self, jsonWriter: com.google.gson.stream.JsonWriter, localDate: java.time.LocalDate) -> None: ...
    class OffsetDateTimeTypeAdapter(com.google.gson.TypeAdapter[java.time.OffsetDateTime]):
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, dateTimeFormatter: java.time.format.DateTimeFormatter): ...
        def read(self, jsonReader: com.google.gson.stream.JsonReader) -> java.time.OffsetDateTime: ...
        def setFormat(self, dateTimeFormatter: java.time.format.DateTimeFormatter) -> None: ...
        def write(self, jsonWriter: com.google.gson.stream.JsonWriter, offsetDateTime: java.time.OffsetDateTime) -> None: ...
    class SqlDateTypeAdapter(com.google.gson.TypeAdapter[java.sql.Date]):
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, dateFormat: java.text.DateFormat): ...
        def read(self, jsonReader: com.google.gson.stream.JsonReader) -> java.sql.Date: ...
        def setFormat(self, dateFormat: java.text.DateFormat) -> None: ...
        def write(self, jsonWriter: com.google.gson.stream.JsonWriter, date: typing.Union[java.sql.Date, datetime.date]) -> None: ...

class StringUtil:
    def __init__(self): ...
    @staticmethod
    def containsIgnoreCase(stringArray: typing.List[java.lang.String], string2: typing.Union[java.lang.String, str]) -> bool: ...
    @staticmethod
    def join(stringArray: typing.List[java.lang.String], string2: typing.Union[java.lang.String, str]) -> java.lang.String: ...

class CollectionFormats:
    def __init__(self): ...
    class CSVParams:
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, *string: typing.Union[java.lang.String, str]): ...
        @typing.overload
        def __init__(self, list: java.util.List[typing.Union[java.lang.String, str]]): ...
        def getParams(self) -> java.util.List[java.lang.String]: ...
        def setParams(self, list: java.util.List[typing.Union[java.lang.String, str]]) -> None: ...
        def toString(self) -> java.lang.String: ...
    class PIPESParams(org.ergoplatform.explorer.client.CollectionFormats.CSVParams):
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, *string: typing.Union[java.lang.String, str]): ...
        @typing.overload
        def __init__(self, list: java.util.List[typing.Union[java.lang.String, str]]): ...
        def toString(self) -> java.lang.String: ...
    class SSVParams(org.ergoplatform.explorer.client.CollectionFormats.CSVParams):
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, *string: typing.Union[java.lang.String, str]): ...
        @typing.overload
        def __init__(self, list: java.util.List[typing.Union[java.lang.String, str]]): ...
        def toString(self) -> java.lang.String: ...
    class TSVParams(org.ergoplatform.explorer.client.CollectionFormats.CSVParams):
        @typing.overload
        def __init__(self): ...
        @typing.overload
        def __init__(self, *string: typing.Union[java.lang.String, str]): ...
        @typing.overload
        def __init__(self, list: java.util.List[typing.Union[java.lang.String, str]]): ...
        def toString(self) -> java.lang.String: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.explorer.client")``.

    CollectionFormats: typing.Type[CollectionFormats]
    DefaultApi: typing.Type[DefaultApi]
    ExplorerApiClient: typing.Type[ExplorerApiClient]
    JSON: typing.Type[JSON]
    StringUtil: typing.Type[StringUtil]
    auth: org.ergoplatform.explorer.client.auth.__module_protocol__
    model: org.ergoplatform.explorer.client.model.__module_protocol__



import java.awt
import java.io
import java.net
import java.util
import javax.accessibility
import typing



class Applet(java.awt.Panel):
    def __init__(self): ...
    def destroy(self) -> None: ...
    def getAccessibleContext(self) -> javax.accessibility.AccessibleContext: ...
    def getAppletContext(self) -> 'AppletContext': ...
    def getAppletInfo(self) -> str: ...
    @typing.overload
    def getAudioClip(self, uRL: java.net.URL) -> 'AudioClip': ...
    @typing.overload
    def getAudioClip(self, uRL: java.net.URL, string: str) -> 'AudioClip': ...
    def getCodeBase(self) -> java.net.URL: ...
    def getDocumentBase(self) -> java.net.URL: ...
    @typing.overload
    def getImage(self, uRL: java.net.URL) -> java.awt.Image: ...
    @typing.overload
    def getImage(self, uRL: java.net.URL, string: str) -> java.awt.Image: ...
    def getLocale(self) -> java.util.Locale: ...
    def getParameter(self, string: str) -> str: ...
    def getParameterInfo(self) -> typing.List[typing.List[str]]: ...
    def init(self) -> None: ...
    def isActive(self) -> bool: ...
    def isValidateRoot(self) -> bool: ...
    @staticmethod
    def newAudioClip(uRL: java.net.URL) -> 'AudioClip': ...
    @typing.overload
    def play(self, uRL: java.net.URL) -> None: ...
    @typing.overload
    def play(self, uRL: java.net.URL, string: str) -> None: ...
    @typing.overload
    def resize(self, int: int, int2: int) -> None: ...
    @typing.overload
    def resize(self, dimension: java.awt.Dimension) -> None: ...
    def setStub(self, appletStub: 'AppletStub') -> None: ...
    def showStatus(self, string: str) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...

class AppletContext:
    def getApplet(self, string: str) -> Applet: ...
    def getApplets(self) -> java.util.Enumeration[Applet]: ...
    def getAudioClip(self, uRL: java.net.URL) -> 'AudioClip': ...
    def getImage(self, uRL: java.net.URL) -> java.awt.Image: ...
    def getStream(self, string: str) -> java.io.InputStream: ...
    def getStreamKeys(self) -> java.util.Iterator[str]: ...
    def setStream(self, string: str, inputStream: java.io.InputStream) -> None: ...
    @typing.overload
    def showDocument(self, uRL: java.net.URL) -> None: ...
    @typing.overload
    def showDocument(self, uRL: java.net.URL, string: str) -> None: ...
    def showStatus(self, string: str) -> None: ...

class AppletStub:
    def appletResize(self, int: int, int2: int) -> None: ...
    def getAppletContext(self) -> AppletContext: ...
    def getCodeBase(self) -> java.net.URL: ...
    def getDocumentBase(self) -> java.net.URL: ...
    def getParameter(self, string: str) -> str: ...
    def isActive(self) -> bool: ...

class AudioClip:
    def loop(self) -> None: ...
    def play(self) -> None: ...
    def stop(self) -> None: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.applet")``.

    Applet: typing.Type[Applet]
    AppletContext: typing.Type[AppletContext]
    AppletStub: typing.Type[AppletStub]
    AudioClip: typing.Type[AudioClip]
